@@ -2,10 +2,10 @@ mod spotify;
 mod utils;
 mod youtube;
 
-use rayon::iter::{IntoParallelIterator, ParallelIterator};
-use std::path::Path;
 use async_std::task::block_on;
 use colored::*;
+use rayon::iter::{IntoParallelIterator, ParallelIterator};
+use std::path::Path;
 
 #[async_std::main]
 async fn main() {
@@ -15,9 +15,9 @@ async fn main() {
     println!("Beginning Playlist Download...");
     let songs = spotify::get_playlist(client_id, client_secret, playlist_id).await;
     songs.into_par_iter().for_each(|song| {
-        let song_name = format!("{}", song).replace("/", "");
-        let s_name = format!("{}", song).replace("/", "");
-        let file_name = format!("{}.mp3", song_name);
+        let song_name = format!("{}", song).replace("/", "|");
+        let s_name = format!("{}", song).replace("/", "|");
+        let file_name = format!("{}.mp3", song_name).replace(|c: char| !c.is_ascii(), "");
         let f_name = format!("{}.mp3", song_name);
 
         if !Path::new(&file_name).exists() {
