@@ -6,9 +6,11 @@ fn download_command(yt_dlp: &str, search_query: String, file_name: String) {
             "-x",
             "--audio-format",
             "mp3",
+            "--playlist-items",
+            "1",
             "--default-search",
-            "ytsearch",
-            &*format!("\"{}\"", search_query),
+            "https://music.youtube.com/search?q=",
+            &*format!("\"{} (Lyrics)\"", search_query),
             "-o",
             &file_name,
         ])
